@@ -199,7 +199,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
             s.mount('https://', HTTPAdapter(max_retries=retries))
 
             url = self._base_url_askdata + '/smartbot/agents/agentslug/' + self._slug + '/datasetslug/' + dataset_slug
-            logging.info("URL {}".format(url))
 
             headers = {"Authorization": "Bearer" + " " + self._token}
             response = s.get(url=url, headers=headers)
@@ -225,8 +224,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
             "pivot": pivot
         }
 
-        print(body)
-
         url = self.smart_insight_url + "/composed_queries/sdk"
 
         s = requests.Session()
@@ -242,8 +239,6 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         preview_url = self.smart_insight_url + "/composed_queries/" + qc_id + "/preview"
 
-        logging.info("CALLING {}".format(preview_url))
-
         s = requests.Session()
         s.keep_alive = False
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
@@ -957,18 +952,23 @@ class Askdata(SignUp):
 
         return df.merge(df_query, how, on, left_on, right_on)
 
-    def load_dataset(self, workspace_slug, dataset_slug):
+    def load_dataset(self, workspace_slug, dataset_slug, logs=True):
         all_fields = list(self.get_columns(workspace=workspace_slug, dataset=dataset_slug)["code"])
         limit = 1000
         df = self.query(workspace=workspace_slug, dataset=dataset_slug, fields=all_fields, limit=limit)
         if(len(df.index) < 1000):
+            print("Downloaded {} rows".format(len(df.index)))
             return df
         else:
             final_df = df
             while(len(df.index) == 1000):
                 df = self.query(workspace=workspace_slug, dataset=dataset_slug, fields=all_fields, limit=1000, offset=limit)
                 final_df = final_df.append(df)
+                if(limit%10000 == 0 and logs):
+                    print("Downloaded {} rows".format(limit))
+
                 limit+=1000
+            print("Downloaded {} rows".format(len(df.index)))
             return final_df
 
     def __retrieve_og_columns(self, conditions:list, df:pd.DataFrame):
